"use strict";

var Promise = require("bluebird");
var Cookies = require('js-cookie');

var Helper = require('./helper');

var GuiConnector = require('./GuiConnector-mock');

var path = require('path');

// -----------------------------

var logger = require('./logger');

function removeCookies() {
  var cookies = Cookies.get();
  for (var cookie in cookies) {
    Cookies.remove(cookie);
  }
}

function mockBootstrap() {
  $.fn.typeahead = function () {
    logger.debug("Mock typeahead function call");
  };
}

before(function () {
  // requirejs.config({
  //   baseUrl: path.dirname(require.main.filename) + "/../../../"
  // });

// GLOBAL configuration
  global.navigator = {
    userAgent: 'node.js',
    appName: 'MinervaUnitTest',
    appVersion: '0.0.1'

  };

  var jsdom = require('jsdom');
  global.dom = new jsdom.JSDOM();
  global.window = global.dom.window;
  global.document = window.document;
  global.document.elementFromPoint = function () {
  };

  global.$ = require('jquery');
  global.jQuery = $;
  global.window.$ = $;

// additions to jsdom implementations:
  global.Option = window.Option;
  global.Blob = window.Blob;
  global.MouseEvent = window.MouseEvent;
  global.FileReader = window.FileReader;

  var originalCreateElement = document.createElement;
  document.createElement = function (arg) {
    var result = originalCreateElement.call(this, arg);
    // workaround for: https://github.com/tmpvar/jsdom/issues/961
    if ("li" === arg) {
      result.dataset = [];
    }
    return result;
  };

  window.open = function () {
    var result = {};
    result.focus = function () {

    };
    return result;
  };
  window.URL.createObjectURL = function () {

  };

// pileup is using heavily some browser defined javascript
  var pileup = require('pileup');
  pileup.create = function () {
    return {
      destroy: function () {
      }
    };
  };
  pileup.formats.twoBit = function () {
    return {};
  };
  pileup.formats.bigBed = function () {
    return {};
  };
// ---

  require('jquery-ui-dist/jquery-ui.js');

  require("bootstrap");

  require('datatables.net')(window, $);
  require('spectrum-colorpicker');
  global.tinycolor = window.tinycolor;
  require('jstree');

  global.google = require('./google-map-mock');

  global.ServerConnector = require('./ServerConnector-mock');

  Promise.longStackTraces();

  mockBootstrap();
});

beforeEach(function () {
  window.onresize = undefined;

  logger.flushBuffer();

  removeCookies();

  ServerConnector.init();

  ServerConnector.getSessionData(null).setToken("MOCK_TOKEN_ID");
  ServerConnector.getSessionData(null).setLogin("anonymous");


  global.testDiv = document.createElement("div");
  global.testDiv.id = "test";
  document.body.appendChild(testDiv);

  return ServerConnector.getConfiguration().then(function (configuration) {
    global.helper = new Helper(configuration);
    helper.setUrl("http://test/");
    GuiConnector.init();
  });

});

afterEach(function () {
  document.body.removeChild(global.testDiv);
  delete global.testDiv;
  if (this.currentTest.state !== 'failed') {
    if (document.body.hasChildNodes()) {
      var content = document.body.innerHTML;
      document.body.innerHTML = "";
      this.test.error(new Error("Test didn't left clean document. Found: " + content));
    } else if ($._data(window, "events").resize) {
      logger.debug($._data(window, "events").resize);
      this.test.error(new Error("Test didn't left clean resize events handlers."));
    }
  }
});
